# sscutils

[![Documentation Status](https://readthedocs.org/projects/sscutils/badge/?version=latest)](https://sscutils.readthedocs.io/en/latest)
[![codeclimate](https://img.shields.io/codeclimate/maintainability/sscu-budapest/sscutils.svg)](https://codeclimate.com/github/endremborza/sscutils)
[![codecov](https://img.shields.io/codecov/c/github/sscu-budapest/sscutils)](https://codecov.io/gh/sscu-budapest/sscutils)
[![pypi](https://img.shields.io/pypi/v/sscutils.svg)](https://pypi.org/project/sscutils/)

Some utility function to help with

- setting up data subsets with invoke
- simplified dvc pipeline registry

these are used in [dataset-template](https://github.com/sscu-budapest/dataset-template) and [research-project-template](https://github.com/sscu-budapest/project-template)